@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::ActivityFact;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -82,9 +83,17 @@ sub as_xml {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::Ohloh::API::ActivityFact - collection of statistics about an Ohloh project
+WWW::Ohloh::API::ActivityFact
+
+=head1 VERSION
+
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -103,6 +112,10 @@ project.
 To be properly populated, it must be retrieved via
 a L<WWW::Ohloh::API::ActivityFacts> object.
 
+=head1 NAME
+
+WWW::Ohloh::API::ActivityFact - collection of statistics about an Ohloh project
+
 =head1 METHODS 
 
 =head2 API Data Accessors
@@ -170,7 +183,6 @@ Please report any bugs or feature requests to
 C<bug-www-ohloh-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Yanick Champoux  C<< <yanick@cpan.org> >>
@@ -182,6 +194,15 @@ Copyright (c) 2008, Yanick Champoux C<< <yanick@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-
