@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::Analysis;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -76,11 +77,20 @@ sub as_xml {
 *language = *main_language = *main_language_name;
 
 'end of WWW::Ohloh::API::Analysis';
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::Ohloh::API::Account - an Ohloh account
+WWW::Ohloh::API::Analysis
+
+=head1 VERSION
+
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -98,6 +108,10 @@ account as defined at http://www.ohloh.net/api/reference/account.
 To be properly populated, it must be created via
 the C<get_account> method of a L<WWW::Ohloh::API> object.
 
+=head1 NAME
+
+WWW::Ohloh::API::Account - an Ohloh account
+
 =head1 METHODS 
 
 =head2 API Data Accessors
@@ -198,7 +212,6 @@ Please report any bugs or feature requests to
 C<bug-www-ohloh-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Yanick Champoux  C<< <yanick@cpan.org> >>
@@ -210,7 +223,15 @@ Copyright (c) 2008, Yanick Champoux C<< <yanick@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=head1 AUTHOR
 
+Yanick Champoux <yanick@cpan.org>
 
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
