@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::Collection;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -100,8 +101,6 @@ sub _gather_more {
     $total_entries_of[$$self] =
       $xml->findvalue('/response/items_available/text()');
 
-    my $first_item = $xml->findvalue('/response/first_item_position/text()');
-
     push @{ $cache_of[$$self] }, @new_batch;
 
     $all_read[$$self] = 1 if $self->total_entries == $self->get_read_so_far;
@@ -126,3 +125,30 @@ sub all {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+WWW::Ohloh::API::Collection
+
+=head1 VERSION
+
+version 1.0.2
+
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
