@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::ContributorLanguageFact;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -80,10 +81,17 @@ sub as_xml {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::Ohloh::API::ContributorLanguageFact - Ohloh stats about a project's
-contributor for a specific language
+WWW::Ohloh::API::ContributorLanguageFact
+
+=head1 VERSION
+
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -94,7 +102,7 @@ contributor for a specific language
         project_id => 12933,
         contributor_id => 1234
     );
-    
+
 =head1 DESCRIPTION
 
 W::O::A::ContributorLanguageFact contains the information associated with 
@@ -104,6 +112,11 @@ To be properly populated, it must be created via
 the C<get_contributor_language_facts> method of a 
 L<WWW::Ohloh::API> object.
 
+=head1 NAME
+
+WWW::Ohloh::API::ContributorLanguageFact - Ohloh stats about a project's
+contributor for a specific language
+
 =head1 METHODS 
 
 =head2 API Data Accessors
@@ -195,7 +208,6 @@ Please report any bugs or feature requests to
 C<bug-www-ohloh-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Yanick Champoux  C<< <yanick@cpan.org> >>
@@ -207,5 +219,15 @@ Copyright (c) 2008, Yanick Champoux C<< <yanick@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=head1 AUTHOR
 
+Yanick Champoux <yanick@cpan.org>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
