@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::Enlistment;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -76,9 +77,17 @@ sub as_xml {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::Ohloh::API::Enlistment - an Ohloh enlistment
+WWW::Ohloh::API::Enlistment
+
+=head1 VERSION
+
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -88,7 +97,7 @@ WWW::Ohloh::API::Enlistment - an Ohloh enlistment
     my @enlistments = $ohloh->get_enlistments( 
         project_id => 12933,
     );
-    
+
 =head1 DESCRIPTION
 
 W::O::A::Enlistment contains the information that join 
@@ -97,6 +106,10 @@ as defined at http://www.ohloh.net/api/reference/enlistment.
 To be properly populated, it must be created via
 the C<get_enlistments> method of a L<WWW::Ohloh::API> object.
 
+=head1 NAME
+
+WWW::Ohloh::API::Enlistment - an Ohloh enlistment
+
 =head1 METHODS 
 
 =head2 API Data Accessors
@@ -161,7 +174,6 @@ Please report any bugs or feature requests to
 C<bug-www-ohloh-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Yanick Champoux  C<< <yanick@cpan.org> >>
@@ -173,5 +185,15 @@ Copyright (c) 2008, Yanick Champoux C<< <yanick@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=head1 AUTHOR
 
+Yanick Champoux <yanick@cpan.org>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
