@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::Factoid;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -71,9 +72,17 @@ sub as_xml {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::Ohloh::API::Factoid - A factoid about an Ohloh project
+WWW::Ohloh::API::Factoid
+
+=head1 VERSION
+
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -88,6 +97,10 @@ WWW::Ohloh::API::Factoid - A factoid about an Ohloh project
 
 W::O::A::Factoid is a bit of information about a project.
 
+=head1 NAME
+
+WWW::Ohloh::API::Factoid - A factoid about an Ohloh project
+
 =head1 METHODS 
 
 =head2 API Data Accessors
@@ -172,7 +185,6 @@ Please report any bugs or feature requests to
 C<bug-www-ohloh-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Yanick Champoux  C<< <yanick@cpan.org> >>
@@ -184,6 +196,15 @@ Copyright (c) 2008, Yanick Champoux C<< <yanick@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-
