@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::Kudo;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -111,11 +112,20 @@ sub as_xml {
 }
 
 'end of WWW::Ohloh::API::Kudo';
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::Ohloh::API::Kudo - an Ohloh kudo
+WWW::Ohloh::API::Kudo
+
+=head1 VERSION
+
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -137,6 +147,10 @@ the C<get_kudos> method of a L<WWW::Ohloh::API> object,
 or via the C<received_kudos>/C<sent_kudos> methods of a 
 L<WWW::Ohloh::API::Account> object.
 
+=head1 NAME
+
+WWW::Ohloh::API::Kudo - an Ohloh kudo
+
 =head1 METHODS 
 
 =head2 API Data Accessors
@@ -209,7 +223,6 @@ Please report any bugs or feature requests to
 C<bug-www-ohloh-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Yanick Champoux  C<< <yanick@cpan.org> >>
@@ -221,3 +234,15 @@ Copyright (c) 2008, Yanick Champoux C<< <yanick@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
