@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::KudoScore;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -51,12 +52,20 @@ sub as_xml {
 }
 
 'end of WWW::Ohloh::API::KudoScore';
+
 __END__
 
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-WWW::Ohloh::API::KudoScore - an Ohloh kudo score
+WWW::Ohloh::API::KudoScore
+
+=head1 VERSION
+
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -75,6 +84,10 @@ account as defined at http://www.ohloh.net/api/reference/kudo_score.
 To be properly populated, it must be retrieved via
 the C<kudo_score> method of a L<WWW::Ohloh::API::Account> object.
 
+=head1 NAME
+
+WWW::Ohloh::API::KudoScore - an Ohloh kudo score
+
 =head1 METHODS 
 
 =head2 API Data Accessors
@@ -96,7 +109,6 @@ The person with `position` equals 1 is the highest-ranked person on Ohloh.
 
 Return the total number of partcipants in the most recent KudoScore calculations. The person whose `position` equals `max_position` is the lowest-ranked person on Ohloh.
 
-
 =head3 position_delta
 
 Return the change in this person's position since the previous kudo score calculations. Here, a negative number represents an improvement, since lower positions are better.
@@ -144,7 +156,6 @@ Please report any bugs or feature requests to
 C<bug-www-ohloh-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Yanick Champoux  C<< <yanick@cpan.org> >>
@@ -156,3 +167,15 @@ Copyright (c) 2008, Yanick Champoux C<< <yanick@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
