@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::Kudos;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -105,11 +106,20 @@ sub sent {
 }
 
 'end of WWW::Ohloh::API::Kudos';
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::Ohloh::API::Kudos - Ohloh kudos sent and received by an account
+WWW::Ohloh::API::Kudos
+
+=head1 VERSION
+
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -128,6 +138,10 @@ an Ohloh account.
 To be properly populated, it must be created via
 the C<get_kudos> method of a L<WWW::Ohloh::API> object. 
 
+=head1 NAME
+
+WWW::Ohloh::API::Kudos - Ohloh kudos sent and received by an account
+
 =head1 METHODS 
 
 =head2 all
@@ -154,7 +168,6 @@ L<WWW::Ohloh::API::Project>,
 L<WWW::Ohloh::API::Analysis>, 
 L<WWW::Ohloh::API::Account>.
 
-
 =item *
 
 Ohloh API reference: http://www.ohloh.net/api/getting_started
@@ -178,7 +191,6 @@ Please report any bugs or feature requests to
 C<bug-www-ohloh-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Yanick Champoux  C<< <yanick@cpan.org> >>
@@ -190,4 +202,15 @@ Copyright (c) 2008, Yanick Champoux C<< <yanick@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
