@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::Language;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -99,9 +100,17 @@ sub is_markup {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::Ohloh::API::Language - a programming language information on Ohloh
+WWW::Ohloh::API::Language
+
+=head1 VERSION
+
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -121,6 +130,10 @@ language recognized by Ohloh as defined at http://www.ohloh.net/api/reference/la
 To be properly populated, it must be created via
 the C<get_languages> or C<get_language> method of a L<WWW::Ohloh::API> object.
 
+=head1 NAME
+
+WWW::Ohloh::API::Language - a programming language information on Ohloh
+
 =head1 METHODS 
 
 =head2 API Data Accessors
@@ -152,7 +165,6 @@ code language.
 Return true if the language is a code language, false if it's a
 markup language.
 
-
 =head3 code
 
 Return the total number of lines of code, excluding comments and blank lines, written
@@ -229,7 +241,6 @@ Please report any bugs or feature requests to
 C<bug-www-ohloh-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Yanick Champoux  C<< <yanick@cpan.org> >>
@@ -241,4 +252,15 @@ Copyright (c) 2008, Yanick Champoux C<< <yanick@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
