@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::Message;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -101,9 +102,17 @@ sub is_markup {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::Ohloh::API::Message - a Ohloh message
+WWW::Ohloh::API::Message
+
+=head1 VERSION
+
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -116,11 +125,14 @@ WWW::Ohloh::API::Message - a Ohloh message
         print $msg->body, "\n";
     }
 
-
 =head1 DESCRIPTION
 
 W::O::A::Message contains the information associated with an Ohloh message.
 
+=head1 NAME
+
+WWW::Ohloh::API::Message - a Ohloh message
+
 =head1 METHODS 
 
 =head2 API Data Accessors
@@ -194,7 +206,6 @@ Please report any bugs or feature requests to
 C<bug-www-ohloh-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Yanick Champoux  C<< <yanick@cpan.org> >>
@@ -206,5 +217,15 @@ Copyright (c) 2008, Yanick Champoux C<< <yanick@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
-=cut
+=head1 AUTHOR
 
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
