@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::Message::Tag;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -64,9 +65,17 @@ sub is_account {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::Ohloh::API::Message::Tag - a tag associated to an Ohloh message 
+WWW::Ohloh::API::Message::Tag
+
+=head1 VERSION
+
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -87,6 +96,10 @@ WWW::Ohloh::API::Message::Tag - a tag associated to an Ohloh message
 W::O::A::Message::Tag contains the information of a tag associated with a 
 message.
 
+=head1 NAME
+
+WWW::Ohloh::API::Message::Tag - a tag associated to an Ohloh message 
+
 =head1 METHODS 
 
 =head2 API Data Accessors
@@ -116,7 +129,6 @@ tagged project or account.
 
 Sets the content of the tag to I<$name>.
 
-
 =head2 Other Methods
 
 =head3 as_xml
@@ -160,7 +172,6 @@ Please report any bugs or feature requests to
 C<bug-www-ohloh-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Yanick Champoux  C<< <yanick@cpan.org> >>
@@ -172,6 +183,15 @@ Copyright (c) 2008, Yanick Champoux C<< <yanick@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-
