@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::Messages;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -68,11 +69,20 @@ sub is_allowed_sort {
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 'end of WWW::Ohloh::API::Messages';
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::Ohloh::API::Languages - a set of Ohloh languages
+WWW::Ohloh::API::Messages
+
+=head1 VERSION
+
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -98,6 +108,10 @@ same time, you can use the B<all()> method:
 
     my @langs = $ohloh->get_languages( sort => 'code' )->all;
 
+=head1 NAME
+
+WWW::Ohloh::API::Languages - a set of Ohloh languages
+
 =head1 METHODS 
 
 =head2 new( %args )
@@ -109,7 +123,7 @@ arguments:
 
 =over
 
-=item  ohloh => I<$ohloh>
+=item ohloh => I<$ohloh>
 
 Mandatory.  Its value is the L<WWW::Ohloh::API> object that will be used
 to query the Ohloh server.
@@ -157,7 +171,6 @@ entries have been added or removed since the last retrieval.
 L<WWW::Ohloh::API>, 
 L<WWW::Ohloh::API::Language>. 
 
-
 =item *
 
 Ohloh API reference: http://www.ohloh.net/api/getting_started
@@ -181,7 +194,6 @@ Please report any bugs or feature requests to
 C<bug-www-ohloh-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Yanick Champoux  C<< <yanick@cpan.org> >>
@@ -193,4 +205,15 @@ Copyright (c) 2008, Yanick Champoux C<< <yanick@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
