@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::Role::Fetchable;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -73,3 +74,30 @@ sub generate_query_url : Chained(bottom up) {
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 'end of WWW::Ohloh::API::Role::Fetchable';
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+WWW::Ohloh::API::Role::Fetchable
+
+=head1 VERSION
+
+version 1.0.2
+
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
