@@ -1,4 +1,5 @@
 package WWW::Ohloh::API::StackEntry;
+our $AUTHORITY = 'cpan:YANICK';
 
 use strict;
 use warnings;
@@ -87,11 +88,20 @@ sub project {
 }
 
 'end of WWW::Ohloh::API::StackEntry';
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::Ohloh::API::StackEntry - A project entry in a stack
+WWW::Ohloh::API::StackEntry
+
+=head1 VERSION
+
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -106,11 +116,14 @@ WWW::Ohloh::API::StackEntry - A project entry in a stack
     my @stacks = $ohloh->get_project_stacks( $project_id );
     my @entries = $stacks[0]->stack_entries;
 
-
 =head1 DESCRIPTION
 
 W::O::A::StackEntry represents one project in a stack.
 
+=head1 NAME
+
+WWW::Ohloh::API::StackEntry - A project entry in a stack
+
 =head1 METHODS 
 
 =head2 API Data Accessors
@@ -155,7 +168,6 @@ by the Ohloh server.
 
 L<WWW::Ohloh::API>. 
 
-
 =item *
 
 Ohloh API reference: http://www.ohloh.net/api/getting_started
@@ -179,7 +191,6 @@ Please report any bugs or feature requests to
 C<bug-www-ohloh-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Yanick Champoux  C<< <yanick@cpan.org> >>
@@ -191,6 +202,15 @@ Copyright (c) 2008, Yanick Champoux C<< <yanick@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025, 2008 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-
